# eric7.WebBrowser.ImageSearch.ImageSearchEngine

Module implementing the image search engine.

### Global Attributes

None

### Classes

ImageSearchEngine | Class implementing the image search engine.

### Functions

None

## ImageSearchEngine

Class implementing the image search engine.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

ImageSearchEngine | Constructor
getSearchQuery | Public method to get the image search query URL.
searchEngine | Public method to get the name of the current search engine.
searchEngineNames | Public method to get the list of supported search engines.
setSearchEngine | Public method to set the current search engine.

### Static Methods

None

#### ImageSearchEngine (Constructor)

ImageSearchEngine(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### ImageSearchEngine.getSearchQuery

getSearchQuery(imageUrl, searchEngine=None)

Public method to get the image search query URL.

imageUrl (QUrl)
  URL of the image to search for
searchEngine (str)
  name of the image search engine to be used

Return:
  search query URL

Return Type:
  QUrl

#### ImageSearchEngine.searchEngine

searchEngine()

Public method to get the name of the current search engine.

Return:
  name of the current search engine

Return Type:
  str

#### ImageSearchEngine.searchEngineNames

searchEngineNames()

Public method to get the list of supported search engines.

Return:
  list of supported search engines

Return Type:
  list of str

#### ImageSearchEngine.setSearchEngine

setSearchEngine(searchEngine)

Public method to set the current search engine.

searchEngine (str)
  name of the search engine

Up